angular.module('cityDue.services', [])

//Load the prediction data to a busstop object for a specified number of items.
.factory('addPredictionToData', ['loadStopPrediction', function (loadStopPrediction){
  return function(busstop, size){
    loadStopPrediction(busstop.id, function(item){
      // console.log("prediction", item);
      var list = item.predictionList;
      list.sort(function(a,b) {return a.time - b.time;} );
      if (list.length>size){
        list.length = size;
      }
      busstop.times = list;
    });
  };
}])
//Geolocation
.factory('geoLocationService', ['$rootScope', function($rootScope){

  return function($scope, callback){

    if (navigator.geolocation) {
      navigator.geolocation.getCurrentPosition(function(position){
        $scope.$apply(function(){
          $rootScope.latitude = position.coords.latitude;
          $rootScope.longitude = position.coords.longitude;
          callback(position.coords.latitude,position.coords.longitude);
        });
      });
    }else{
      callback({latitude:null, longitude:null});
    }
  };

}])
//list the bookmarked items
.factory('listBookmark', [function(){
  return function(bookmarkItem){

    var localBookmark;
    if (localStorage.bookmark){
      localBookmark = localStorage.bookmark.split(',');
    }else{
      localBookmark = [];
    }
    if(bookmarkItem){
      return localBookmark.indexOf(bookmarkItem)>=0;
    }else{
      return localBookmark;
    } 
  };
}])
//Load the prediction for a specific bus stop Id
.factory('loadStopPrediction', ['$http', function($http){
  return function (stopId, callback){
    var timeUrl = "http://lolados.com/mob/lbse/service/times.php?stopid=" + stopId;
    $http.get(timeUrl)
      .success(function(item){
        var bus, busStop, busItem, tempList, i, t;
        busStop = item.list;
        busStop.predictionList.sort(function(a,b){return a.time-b.time});
        tempList = [];
        for(i=0,t=busStop.predictionList.length;i<t;i++){
          bus = busStop.predictionList[i];
          busItem = tempList[bus.lineId];
          if (!busItem){
            bus.nextTime = [];
            tempList[bus.lineId] = bus;
            busItem = bus;
          }
          busItem.nextTime.push(bus.time);
        }
        busStop.buses = [];
        tempList.forEach(function(element){busStop.buses.push(element)});
        callback(busStop);
    });
  };
}])
//loadStop
.factory('loadStops', ['$http', function($http) {
  return function(latitude, longitude, callback) {
    var url = 'http://lolados.com/mob/lbse/service/stop.php?stop=pedro&lat='+latitude+'&long='+longitude;
    var successLoaded = function(data){
        callback(data.list);
    };
    $http.get(url).success(successLoaded);
  } ;
}])
//loadStop
.factory('loadStopsFromList', ['$http', function($http) {
  return function(stops, latitude, longitude, callback) {
    var stopsString = stops.join(",");
    var url = 'http://lolados.com/mob/lbse/service/stop.php?stops='+stopsString+'&lat='+latitude+'&long='+longitude;
    var successLoaded = function(data){
        callback(data.list);
    };
    $http.get(url).success(successLoaded);
  } ;
}])
//Add and remove the bookmark
.factory('toggleBookmark', [function(){
  return function(bookmarkItem){

    var localBookmark;
    if (localStorage.bookmark){
      localBookmark = localStorage.bookmark.split(',');
    }else{
      localBookmark = [];
    }
    var index = localBookmark.indexOf(bookmarkItem);
    if (index >=0){
      localBookmark.splice(index,1);
    }else{
      localBookmark.push(bookmarkItem);
    }
    localStorage.bookmark = localBookmark.join(',');
  };
}]);
